Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1074)

Unified Diff: src/heap/heap.h

Issue 1368833004: Revert of [heap] Move large object space selection into AllocateRaw. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/heap/heap.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/heap/heap.h
diff --git a/src/heap/heap.h b/src/heap/heap.h
index 442d4dee1ace9108b8aa6b0a4a4e060e2aaacc15..3b6fd98da4f9cbe762c1754c2cdd0525e32065fe 100644
--- a/src/heap/heap.h
+++ b/src/heap/heap.h
@@ -1640,8 +1640,10 @@
static void ScavengeStoreBufferCallback(Heap* heap, MemoryChunk* page,
StoreBufferEvent event);
- // Selects the proper allocation space based on the pretenuring decision.
- static AllocationSpace SelectSpace(PretenureFlag pretenure) {
+ // Selects the proper allocation space depending on the given object
+ // size and pretenuring decision.
+ static AllocationSpace SelectSpace(int object_size, PretenureFlag pretenure) {
+ if (object_size > Page::kMaxRegularHeapObjectSize) return LO_SPACE;
return (pretenure == TENURED) ? OLD_SPACE : NEW_SPACE;
}
« no previous file with comments | « no previous file | src/heap/heap.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698